==> mingw-w64-i686-eccodes-2.19.1-1-any.pkg.tar.zst: mingw32/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef eccodes_ecbuild_config_h
#define eccodes_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.4.1"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.4.1"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "C:/_/M/mingw-w64-eccodes/src/eccodes-2.19.1-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Windows-10.0.17763"
#define ECCODES_OS_BITS          32
#define ECCODES_OS_BITS_STR      "32"
#define ECCODES_OS_STR           "windows.32"
#define ECCODES_OS_VERSION       "10.0.17763"
#define ECCODES_SYS_PROCESSOR    "AMD64"

#define ECCODES_BUILD_TIMESTAMP  ""
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "GNU"
#define ECCODES_C_COMPILER_VERSION "10.2.0"

#define ECCODES_CXX_COMPILER_ID      ""
#define ECCODES_CXX_COMPILER_VERSION ""

#define ECCODES_C_COMPILER       "D:/a/_temp/msys/msys64/mingw32/bin/gcc.exe"
#define ECCODES_C_FLAGS          "-march=i686 -mtune=generic -O2 -pipe -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     ""
#define ECCODES_CXX_FLAGS        ""

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/mingw32"
#define ECCODES_INSTALL_BIN_DIR   "/mingw32/bin"
#define ECCODES_INSTALL_LIB_DIR   "/mingw32/lib"
#define ECCODES_INSTALL_DATA_DIR  "/mingw32/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "C:/_/M/mingw-w64-eccodes/src/eccodes-2.19.1-Source"
#define ECCODES_DEVELOPER_BIN_DIR "C:/_/M/mingw-w64-eccodes/src/build-i686-w64-mingw32"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* eccodes_ecbuild_config_h */

==> mingw-w64-i686-eccodes-2.19.1-3-any.pkg.tar.zst: mingw32/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef eccodes_ecbuild_config_h
#define eccodes_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.4.1"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.4.1"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "C:/M/mingw-w64-eccodes/src/eccodes-2.19.1-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Windows-10.0.20348"
#define ECCODES_OS_BITS          32
#define ECCODES_OS_BITS_STR      "32"
#define ECCODES_OS_STR           "windows.32"
#define ECCODES_OS_VERSION       "10.0.20348"
#define ECCODES_SYS_PROCESSOR    "AMD64"

#define ECCODES_BUILD_TIMESTAMP  ""
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "GNU"
#define ECCODES_C_COMPILER_VERSION "12.1.0"

#define ECCODES_CXX_COMPILER_ID      ""
#define ECCODES_CXX_COMPILER_VERSION ""

#define ECCODES_C_COMPILER       "D:/a/msys64/mingw32/bin/gcc.exe"
#define ECCODES_C_FLAGS          "-march=pentium4 -mtune=generic -O2 -pipe -pipe -O3 -DNDEBUG"

#define ECCODES_CXX_COMPILER     ""
#define ECCODES_CXX_FLAGS        ""

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/mingw32"
#define ECCODES_INSTALL_BIN_DIR   "/mingw32/bin"
#define ECCODES_INSTALL_LIB_DIR   "/mingw32/lib"
#define ECCODES_INSTALL_DATA_DIR  "/mingw32/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "C:/M/mingw-w64-eccodes/src/eccodes-2.19.1-Source"
#define ECCODES_DEVELOPER_BIN_DIR "C:/M/mingw-w64-eccodes/src/build-i686-w64-mingw32"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* eccodes_ecbuild_config_h */
